# CLI home.nix
{ config, lib, pkgs, inputs, user, ... }:
{
  imports = [
    ../base/home.nix
  ];
  home.shellAliases = {
    wget = "wget --hsts-file=${config.xdg.configHome}/wget-hsts";
    ls = "ls -l";
    ll = "ls -alF";
    trim = "awk '{\$1=\$1;print}'";
  };
  home.sessionPath = [
    "${config.home.homeDirectory}/.local/share/go/bin"
  ];
  xdg = {
    userDirs = {
      enable = true;
      createDirectories = true;
      desktop = "${config.home.homeDirectory}/Desktop";
      documents = "${config.home.homeDirectory}/Documents";
      download = "${config.home.homeDirectory}/Downloads";
      music = "${config.home.homeDirectory}/Music";
      pictures = "${config.home.homeDirectory}/Pictures";
      publicShare = "${config.home.homeDirectory}/Public";
      templates = "${config.home.homeDirectory}/Templates";
      videos = "${config.home.homeDirectory}/Videos";
    };
  };
  programs.fzf = {
    enable = true;
    tmux.enableShellIntegration = true;
  };
  programs.go = {
    goPath = "${config.xdg.dataHome}/go";
  };
  programs.yt-dlp = {
    extraConfig = ''
                  --update
    '';
    settings = {
      embed-thumbnail = true;
      embed-subs = true;
      sub-langs = "all";
      downloader = "aria2c";
      downloader-args = "aria2c:'-c -x8 -s8 -k1M'";
    };
  };
}
