# GUI configuration.nix
{ config, lib, pkgs, inputs, user, ... }:
{
  imports = [
    ../cli
  ];
  xdg = {
    autostart.enable = true;
    mime = {
      enable = true;
      defaultApplications = {
        "image/*" = [
          "imv.desktop"
        ];
        "text/*" = [
          "${user.browser}.desktop"
        ];
        "video/*" = [
          "mpv.desktop"
        ];
      };
    };
    portal = {
      enable = true;
      xdgOpenUsePortal = true;
      extraPortals = [
        pkgs.xdg-desktop-portal-wlr
      ];
      configPackages = [
        pkgs.xdg-desktop-portal-wlr
      ];
      wlr = {
        enable = true;
      };
    };
  };
  environment = {
    systemPackages = with pkgs; [
      libnotify
      networkmanagerapplet
      xdragon
      xdg-utils
    ];
    variables = {
      BROWSER = "${user.browser}";
      TERMINAL = "${user.term}";
      VISUAL = "$EDITOR";
    };
    sessionVariables = {
      SYSTEMD_PAGER = "";
      INPUTRC = "$XDG_CONFIG_HOME/inputrc";
      LIBSEAT_BACKEND = "logind";
      BEMENU_OPTS = ''
        --fn 'Comic Mono 12' \
        --tb '#6272a4' \
        --tf '#f8f8f2' \
        --fb '#282a36' \
        --ff '#f8f8f2' \
        --nb '#282a36' \
        --nf '#6272a4' \
        --hb '#44475a' \
        --hf '#50fa7b' \
        --sb '#44475a' \
        --sf '#50fa7b' \
        --scb '#282a36' \
        --scf '#ff79c6' \
        --hp '10' \
        --binding 'vim' \
        --vim-esc-exits \
        --ignorecase --no-overlap
      '';
    };
  };
  fonts.packages = with pkgs; [
    comic-mono
    noto-fonts
    noto-fonts-cjk
    noto-fonts-emoji
    fira-code
    fira-code-symbols
    fira-code-nerdfont
    dina-font
  ];
  programs.dconf = {
    enable = true;
  };
  programs.river = {
    enable = true;
    extraPackages = with pkgs; [
      bemenu
      bemoji
      cliphist
      foot
      grim
      kanshi
      mako
      pinentry-bemenu
      river-tag-overlay
      slurp
      swappy
      swaylock
      swww
      tessen
      waybar
      wev
      wf-recorder
      wl-clipboard
      wtype
    ];
  };
  # Run the following to add the Flathub repo: `flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo`
  services.flatpak = {
    enable = true;
  };
  services.dbus = {
    enable = true;
  };
  services.seatd = {
    enable = true;
  };
  users.users.${user.name}.packages = with pkgs; [
    glib
    xdg-desktop-portal-wlr
  ];
}
