# Buckwheat configuration.nix
{ config, lib, pkgs, inputs, user, ... }:
let
  hostname="buckwheat";
in
{
  imports = [
    ./hardware-configuration.nix
    ../../modules/nixos/full.nix
  ];
  networking = {
    hostName = "${hostname}";
    firewall = {
      allowedTCPPorts = [ 445 139 ];
      allowedUDPPorts = [ 137 138 ];
    };
    wireless.enable = false;
  };
  services = {
    greetd = {
      enable = true;
      settings = {
        default_session = {
          #command = "${pkgs.greetd.tuigreet}/bin/tuigreet -c river";
          command = "${pkgs.greetd.greetd}/bin/agreety --cmd river";
        };
      };
    };
    davfs2 = {
      enable = true;
    };
    mullvad-vpn = {
      enable = true;
      package = pkgs.mullvad-vpn;
    };
    borgbackup = {
      jobs."daily" = {
        paths = [
          "/home"
          "/var"
        ];
        exclude = [
          "/home/*/go/bin"
          "/home/*/go/pkg"
          "/var/lib/libvirt/images/*.qcow2"
        ];
        repo = "/mnt/archive/buckwheat";
        encryption = {
          mode = "repokey-blake2";
          passCommand = "cat /root/borgbackup/passphrase";
        };
        compression = "auto,lzma";
        startAt = "daily";
        prune.keep = {
          within = "30d";
        };
      };
    };
  };
  users.users.${user.name} = {
    extraGroups = [ "davfs2" ];
    packages = with pkgs; [
      bitwarden
      btfs
      cava
      lavat
      nushell
      python311Packages.eyeD3
      tagutil
      #greetd.tuigreet
    ];
  };
  system.stateVersion = "23.11";
}
