# Hosts default.nix
{ lib, inputs, system, home-manager, user, ... }:
{
  buckwheat = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user inputs; };
    modules = [ 
      ../cores/gui
      ./buckwheat/configuration.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user inputs; };
        home-manager.users.${user.name} = {
          imports = [
            ../cores/gui/home.nix
            ./buckwheat/home.nix
          ];
        };
      }
    ];
  };
  fireweed = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user inputs; };
    modules = [ 
      ../cores/gui
      ./fireweed/configuration.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user; };
        home-manager.users.${user.name} = {
          imports = [
            ../cores/gui/home.nix
            ./fireweed/home.nix
          ];
        };
      }
    ];
  };
  clover = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user inputs; };
    modules = [ 
      ../cores/gui
      ./clover/configuration.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user; };
        home-manager.users.${user.name} = {
          imports = [
            ../cores/gui/home.nix
            ./clover/home.nix
          ];
        };
      }
    ];
  };
  base = lib.nixosSystem {
    inherit system;
    specialArgs = { inherit user inputs; };
    modules = [ 
      ../cores/base
      ./base/configuration.nix
      home-manager.nixosModules.home-manager {
        home-manager.useGlobalPkgs = true;
        home-manager.useUserPackages = true;
        home-manager.extraSpecialArgs = { inherit user; };
        home-manager.users.${user.name} = {
          imports = [
            ../cores/base/home.nix
          ];
        };
      }
    ];
  };
}
